@@ -1,4 +1,5 @@
 """High-Level file manipulation."""
+
 from __future__ import annotations
 
 import fnmatch
@@ -117,9 +118,11 @@ def directory_content(
             result.append(os.path.join(root, d) + os.sep)
     if not include_root_dir:
         result = [
-            os.path.relpath(e, path) + os.sep
-            if e.endswith(os.sep)
-            else os.path.relpath(e, path)
+            (
+                os.path.relpath(e, path) + os.sep
+                if e.endswith(os.sep)
+                else os.path.relpath(e, path)
+            )
             for e in result
         ]
     if unixpath:
@@ -215,7 +218,7 @@ def get_filetree_state(
             return f.read()
 
     path = os.path.abspath(path)
-    result = hashlib.sha1()
+    result = hashlib.sha1()  # nosec
     if os.path.isdir(path):
         for root, dirs, files in os.walk(path):
             if ignore_hidden:
@@ -436,11 +439,10 @@ def rm(path: str | list[str], recursive: bool = False, glob: bool = True) -> Non
 
         :param func: function to call on error
         :param error_path: file or directory to remove
-        :param exc_info: exception raised when the first delete attempt was
-             made
+        :param exc_info: exception raised when the first delete attempt was made
         """
         del exc_info
-        e3.log.debug("error when running %s on %s", func, error_path)
+        e3.log.debug(f"error when running {func.__name__!r} on {error_path}")
 
         # First check whether the file we are trying to delete exist. If not
         # the work is already done, no need to continue trying removing it.
@@ -478,6 +480,9 @@ def rm(path: str | list[str], recursive: bool = False, glob: bool = True) -> Non
             # And continue to delete the subdir
             shutil.rmtree(error_path, onerror=onerror)
 
+        else:
+            raise FSError(origin="rm", message=f"unknown function: {func.__name__!r}")
+
     for f in file_list:
         try:
             # When calling rmtree or remove, ensure that the string that is
@@ -551,8 +556,10 @@ VCS_IGNORE_LIST = (
     ".idea",
     ".python-version",
     ".gitlab-ci",
+    ".gitlab-ci.yml",
     ".vscode",
     ".github",
+    "comment",
 )
 
 
@@ -750,8 +757,9 @@ def sync_tree(
         :param src: the source FileInfo object
         :param dst: the target FileInfo object
         """
+        mode = stat.S_IMODE(src.stat.st_mode)
+
         if islink(src):  # windows: no cover
-            mode = stat.S_IMODE(src.stat.st_mode)
             if hasattr(os, "lchmod"):
                 getattr(os, "lchmod")(dst.path, mode)  # noqa: B009
 
@@ -766,8 +774,9 @@ def sync_tree(
                         or why.errno != errno.EOPNOTSUPP
                     ):
                         raise
+
+                    logger.debug("lchflags: operation not supported [EOPNOTSUPP]")
         else:
-            mode = stat.S_IMODE(src.stat.st_mode)
             if hasattr(os, "utime"):
                 if preserve_timestamps:
                     os.utime(dst.path, (src.stat.st_atime, src.stat.st_mtime))
@@ -787,6 +796,8 @@ def sync_tree(
                     ):
                         raise
 
+                    logger.debug("chflags: operation not supported [EOPNOTSUPP]")
+
     def safe_copy(src: FileInfo, dst: FileInfo) -> None:
         """Copy src file into dst preserving all attributes.
 
@@ -807,7 +818,7 @@ def sync_tree(
                 rm(dst.path, recursive=True, glob=False)
             elif islink(dst):
                 # dst symlink will be replaced by a file having the same
-                #  content as 'src'
+                # content as 'src'
                 rm(dst.path, recursive=False, glob=False)
 
             try:
